@@ -6,6 +6,7 @@ import yaml
 from jsonschema import validate
 
 import packratt
+from packratt.directories import user_config_dir
 
 SCHEMA_PATH = Path(Path(packratt.__file__).parent,
                    "conf", "registry-schema.yaml")
@@ -21,15 +22,19 @@ ENTRY_SCHEMA = {**SCHEMA, "entry": {"type": {"$ref": "/definitions/entry"}}}
 del SCHEMA_PATH
 
 
-def load_registry(filename=None):
+USER_REGISTRY = Path(user_config_dir, "registry.yaml")
 
-    if filename is None:
-        path = Path(Path(packratt.__file__).parent,
-                    "conf", "registry.yaml")
+
+def load_registry(filename=None):
+    path = Path(Path(packratt.__file__).parent, "conf", "registry.yaml")
 
     with open(path, "r") as f:
         registry = yaml.safe_load(f)
 
+    if USER_REGISTRY.is_file():
+        with open(USER_REGISTRY, "r") as f:
+            registry.update(yaml.safe_load(f))
+
     validate(registry, schema=REGISTRY_SCHEMA)
 
     return registry
